/*
 * Created by SharpDevelop.
 * User: xxxx
 * Date: 2007/09/11
 * Time: 21:22
 * 
 * To change this template use Tools | Options | Coding | Edit Standard Headers.
 */

using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Diagnostics;

namespace subtitle_convert
{
	/// <summary>
	/// Description of SubtitleConvert.
	/// </summary>
	public class SubtitleConvert
	{
		public SubtitleConvert()
		{
			//
		}
		
		public string swfc_filename = "swfc.exe";
		public string template_splitter = "\\/\\/\\%\\%transtext\\%\\%";
		public string push_jp_text_template = "\t\tjp_text.push(\"%%TEXT%%\");";
		public string push_en_text_template = "\t\ten_text.push(\"%%TEXT%%\");";
		
		public string loadTemplate(string template_filename)
		{
			StreamReader reader = new StreamReader(
				template_filename,
				Encoding.GetEncoding("UTF-8")
			);
			string template = reader.ReadToEnd();
			reader.Close();
			
			return template;
		}
		
		public void convertSubtitle(StreamWriter writer, string subtitle_filename)
		{
			StreamReader reader = new StreamReader(
				subtitle_filename,
				Encoding.GetEncoding("UTF-8")
			);
			string line = "";
			int line_num = 1;
			while ((line = reader.ReadLine()) != null)
			{
				if ((line_num % 2) == 1)
				{
					this.writeEnSubtitle(writer, line);
				}
				else
				{
					this.writeJpSubtitle(writer, line);
				}
				line_num++;
			}
			reader.Close();
		}
		
		public void writeEnSubtitle(StreamWriter writer, string en_text)
		{
			writer.WriteLine(
				this.push_en_text_template.Replace(
					"%%TEXT%%",
					escapeSpecialChars(en_text)
				)
			);
		}

		public void writeJpSubtitle(StreamWriter writer, string jp_text)
		{
			writer.WriteLine(
				this.push_jp_text_template.Replace(
					"%%TEXT%%",
					escapeSpecialChars(jp_text)
				)
			);
		}

		public string escapeSpecialChars(string src_text)
		{
			string work_text = src_text;
			
			work_text = work_text.Replace("\"", "\\\"");
			
			return work_text;
		}
		
		public void execute(string template_filename, string output_filename, string subtitle_dir)
		{
			string[] templates = Regex.Split(loadTemplate(template_filename), this.template_splitter);
			StreamWriter writer = new StreamWriter(output_filename);
			
			writer.WriteLine(templates[0]);
			
			DirectoryInfo dirinfo = new DirectoryInfo(subtitle_dir);
			foreach(FileInfo file in dirinfo.GetFiles())
			{
				if(file.Extension.ToUpper() == ".TXT")
				{
					Console.WriteLine(file.FullName);
					convertSubtitle(writer, file.FullName);
				}
			}
			
			writer.WriteLine(templates[1]);
			
			writer.Close();
			compile(output_filename);
		}
		
		private void compile(string sc_filename)
		{
			Process swfc = new Process();
			swfc.StartInfo.FileName = this.swfc_filename;
			swfc.StartInfo.Arguments = sc_filename;
			swfc.Start();
		}
	}
}
